Parametrization API
*******************

Providing arguments for dynamic parametrization
===============================================

The following objects help to provide parameters inside the dynamic parametrization decorator
:meth:`balder.parametrize_by_feature`.

The ``Value`` object
--------------------

.. autoclass:: balder.parametrization.Value
    :members:


The ``Parameter`` object
------------------------

.. autoclass:: balder.parametrization.Parameter
    :members:


The ``FeatureAccessSelector`` object
------------------------------------

.. autoclass:: balder.parametrization.FeatureAccessSelector
    :members:
